aboutsummaryrefslogtreecommitdiff
path: root/src/presentation.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/presentation.h')
-rw-r--r--src/presentation.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/presentation.h b/src/presentation.h
index 72a1512..daa016b 100644
--- a/src/presentation.h
+++ b/src/presentation.h
@@ -55,8 +55,6 @@ struct slide
struct frame
{
- PangoContext *pc; /* FIXME: Doesn't belong here */
-
struct frame **rendering_order;
int num_ro;
int max_ro;
@@ -66,12 +64,14 @@ struct frame
struct layout_parameters lop;
struct style *style; /* Non-NULL if 'lop' came from SS */
/* Location relative to parent, calculated from alignment parameters */
double offs_x;
double offs_y;
double w;
double h;
+ PangoLayout *pl;
+
/* True if this frame should be deleted on the next mouse click */
int empty;
};
@@ -66,12 +64,14 @@ struct frame
struct layout_parameters lop;
struct style *style; /* Non-NULL if 'lop' came from SS */
- /* Location relative to parent, calculated from alignment parameters */
+ /* Location relative to parent, calculated from layout parameters */
double offs_x;
double offs_y;